//
/*-
 * ---license-start
 * eu-digital-green-certificates / dgca-wallet-app-ios
 * ---
 * Copyright (C) 2021 T-Systems International GmbH and all other contributors
 * ---
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ---license-end
 */
//  
//  CellWithTitleAndDescriptionTVC.swift
//  DGCAWallet
//  
//  Created by Alexandr Chernyy on 08.07.2021.
//  
        

import UIKit

class CellWithTitleAndDescriptionTVC: UITableViewCell {
  @IBOutlet weak var titleLabel: UILabel!
  @IBOutlet weak var descriptionLabel: UILabel!
  
  private weak var cellModel: ValidityCellModel? {
    didSet {
      self.setupView()
    }
  }
  
  override func awakeFromNib() {
    super.awakeFromNib()
    setInitialStrings()
  }

  override func prepareForReuse() {
    super.prepareForReuse()
    setInitialStrings()
  }
  
  func setupCell(with model: ValidityCellModel) {
    self.cellModel = model
  }
  
  private func setInitialStrings() {
    titleLabel.text = ""
    descriptionLabel.text = ""
  }
  
  private func setupView() {
    guard let cellModel = cellModel else {
      setInitialStrings()
      return
    }
    titleLabel.text = cellModel.title
    descriptionLabel.text = cellModel.description
    if cellModel.needChangeTitleFont {
      titleLabel.font = UIFont.boldSystemFont(ofSize: 24)
    } else {
      titleLabel.font = UIFont.boldSystemFont(ofSize: 14)
    }
  }
  
}
